[Zope-Checkins] CVS: Zope/lib/python/OFS - IOrderSupport.py:1.1.2.2

Yvo Schubbe schubbe@web.de
Mon, 5 May 2003 06:06:04 -0400


Update of /cvs-repository/Zope/lib/python/OFS
In directory cvs.zope.org:/tmp/cvs-serv29837

Modified Files:
      Tag: yuppie-ordersupport-branch
	IOrderSupport.py 
Log Message:
improved docstring


=== Zope/lib/python/OFS/IOrderSupport.py 1.1.2.1 => 1.1.2.2 ===
--- Zope/lib/python/OFS/IOrderSupport.py:1.1.2.1	Fri Apr 25 09:07:21 2003
+++ Zope/lib/python/OFS/IOrderSupport.py	Mon May  5 06:06:03 2003
@@ -32,8 +32,11 @@
         the bottom. If delta is lower than the possible minimum, objects will
         be moved to the top.
 
-        The order of the objects specified by ids will always be preserved. If
-        an object with id doesn't exist an error will be raised.
+        The order of the objects specified by ids will always be preserved. So
+        if you don't want to change their original order, make sure the order
+        of ids corresponds to their original order.
+
+        If an object with id doesn't exist an error will be raised.
 
         Permission -- Manage properties
 
@@ -42,7 +45,7 @@
 
     def moveObjectsUp(ids, delta=1):
         """ Move specified sub-objects up by delta in container.
-        
+
         If no delta is specified, delta is 1. See moveObjectsByDelta for more
         details.